@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gda.cc 1760 2008-11-01 09:15:20Z jhs $ */
+/* $Id: generate_defs_gda.cc 2019 2009-01-27 08:29:42Z murrayc $ */
 
 /* generate_defs_gda.h
  *
@@ -12,9 +12,9 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -54,7 +54,6 @@ int main (int argc, char *argv[])
     << get_defs (GDA_TYPE_SERVER_PROVIDER)
     << get_defs (GDA_TYPE_SET)
     << get_defs (GDA_TYPE_STATEMENT)
-    << get_defs (GDA_TYPE_THREADER)
     << get_defs (GDA_TYPE_TRANSACTION_STATUS)
     << get_defs (GDA_TYPE_XA_TRANSACTION)
     << get_defs (GDA_TYPE_SQL_PARSER)
